@@ -20,8 +20,8 @@
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
-#' # Show the build times for the basic example.
-#' load_basic_example() # Get the code with drake_example("basic").
+#' # Show the build times for the mtcars example.
+#' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' make(my_plan) # Build all the targets.
 #' build_times() # Show how long it took to build each target.
 #' build_times(starts_with("coef")) # `dplyr`-style `tidyselect`
@@ -38,6 +38,7 @@ build_times <- function(
   jobs = 1,
   type = c("build", "command")
 ){
+  eval(parse(text = "require(methods, quietly = TRUE)")) # needed for lubridate
   if (is.null(cache)){
     return(empty_times())
   }
