@@ -8,9 +8,11 @@ colors <- c(
   cache = "skyblue1",
   check = "skyblue1",
   connect = "skyblue1",
+  launch = "#ff9933",
   load = "#ff9933",
   unload = "#ff7221",
   trigger = "maroon",
+  skip = "skyblue1",
   retry = "forestgreen",
   fail = "red",
   up_to_date = "forestgreen",
