@@ -75,14 +75,16 @@
 #'   For example, \code{function(code){force(code)}} is a good hook
 #'   and \code{function(code){message("Avoiding the code")}} is a bad hook.
 #'
-#' @param imports_only logical, whether to skip building the targets
+#' @param skip_targets logical, whether to skip building the targets
 #'   in `plan` and just import objects and files.
 #'
+#' @param imports_only deprecated. Use `skip_targets` instead.
+#'
 #' @param parallelism character, type of parallelism to use.
 #'   To list the options, call [parallelism_choices()].
-#'   For detailed explanations, see \code{?\link{parallelism_choices}},
-#'   the tutorial vignettes, or the tutorial files generated by
-#'   \code{\link{drake_example}("basic")}
+#'   For detailed explanations, see the
+#'   [high-performance computing chapter](https://ropenscilabs.github.io/drake-manual/store.html) # nolint
+#'   of the user manual.
 #'
 #' @param jobs number of parallel processes or jobs to run.
 #'   See [max_useful_jobs()] or [vis_drake_graph()]
@@ -146,8 +148,7 @@
 #'   and then once again for each target right before that target is built.
 #'
 #' @param prepend lines to prepend to the Makefile if `parallelism`
-#'   is `"Makefile"`. See the vignettes
-#'   (`vignette(package = "drake")`)
+#'   is `"Makefile"`. See the [high-performance computing guide](https://ropenscilabs.github.io/drake-manual/store.html) # nolint
 #'   to learn how to use `prepend`
 #'   to take advantage of multiple nodes of a supercomputer.
 #'
@@ -260,12 +261,11 @@
 #'   `make(..., parallelism = "future_lapply", lazy_load = "bind")`.
 #'
 #'   If `lazy_load` is `"eager"`,
-#'   drake prunes the execution environment before every
-#'   parallelizable stages, removing all superfluous targets
-#'   and then loading any dependencies it will need
-#'   for the targets in the current parallelizable stage.
+#'   drake prunes the execution environment before each target/stage,
+#'   removing all superfluous targets
+#'   and then loading any dependencies it will need for building.
 #'   In other words, drake prepares the environment in advance
-#'   for all the whole collection of targets in the stage.
+#'   and tries to be memory efficient.
 #'   If `lazy_load` is `"bind"` or `"promise"`, drake assigns
 #'   promises to load any dependencies at the last minute.
 #'   Lazy loading may be more memory efficient in some use cases, but
@@ -321,10 +321,44 @@
 #'   but it causes [make()] to populate your workspace/environment
 #'   with the last few targets it builds.
 #'
+#' @param pruning_strategy Character scalar, either `"speed"` (default)
+#'   or `"memory"`. These are alternative approaches to how `drake`
+#'   keeps non-import dependencies in memory when it builds a target.
+#'   If `pruning_strategy` is `"memory"`, `drake` removes all targets
+#'   from memory (i.e. `config$envir`) except the direct dependencies
+#'   of the target is about to build. This is suitable for data so large
+#'   that the optimal strategy is to minimize memory consumption.
+#'   If `pruning_strategy` is `"speed"`, `drake` loads all the dependencies
+#'   and keeps in memory everything that will eventually be a
+#'   dependency of a downstream target. This strategy consumes more
+#'   memory, but does more to minimize the number of times data is
+#'   read from storage/disk.
+#'
+#' @param makefile_path Path to the `Makefile` for
+#'   `make(parallelism = "Makefile")`. If you set this argument to a
+#'   non-default value, you are responsible for supplying this same
+#'   path to the `args` argument so `make` knows where to find it.
+#'   Example: `make(parallelism = "Makefile", makefile_path = ".drake/.makefile", command = "make", args = "--file=.drake/.makefile")` # nolint
+#'
+#' @param console_log_file character scalar or `NULL`.
+#'   If `NULL`, console output will be printed
+#'   to the R console using `message()`.
+#'   Otherwise, `console_log_file` should be the name of a flat file.
+#'   Console output will be appended to that file.
+#'
+#' @param ensure_workers logical, whether the master process
+#'   should wait for the workers to post before assigning them
+#'   targets. Should usually be `TRUE`. Set to `FALSE`
+#'   for `make(parallelism = "future_lapply", jobs = n)`
+#'   (`n > 1`) when combined with `future::plan(future::sequential)`. 
+#'   This argument only applies to parallel computing with persistent workers
+#'   (`make(parallelism = x)`, where `x` could be `"mclapply"`,
+#'   `"parLapply"`, or `"future_lapply"`).
+#'
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
-#' load_basic_example() # Get the code with drake_example("basic").
+#' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' # Construct the master internal configuration list.
 #' con <- drake_config(my_plan)
 #' # These functions are faster than otherwise
@@ -345,7 +379,8 @@ drake_config <- function(
   envir = parent.frame(),
   verbose = drake::default_verbose(),
   hook = default_hook,
-  cache = drake::get_cache(verbose = verbose, force = force),
+  cache = drake::get_cache(
+    verbose = verbose, force = force, console_log_file = console_log_file),
   fetch_cache = NULL,
   parallelism = drake::default_parallelism(),
   jobs = 1,
@@ -366,7 +401,7 @@ drake_config <- function(
   log_progress = FALSE,
   graph = NULL,
   trigger = drake::default_trigger(),
-  imports_only = FALSE,
+  skip_targets = FALSE,
   skip_imports = FALSE,
   skip_safety_checks = FALSE,
   lazy_load = "eager",
@@ -375,22 +410,36 @@ drake_config <- function(
   seed = NULL,
   caching = c("worker", "master"),
   keep_going = FALSE,
-  session = NULL
+  session = NULL,
+  imports_only = NULL,
+  pruning_strategy = c("speed", "memory"),
+  makefile_path = "Makefile",
+  console_log_file = NULL,
+  ensure_workers = TRUE
 ){
   force(envir)
+  unlink(console_log_file)
+  if (!is.null(imports_only)){
+    warning(
+      "Argument imports_only is deprecated. Use skip_targets instead.",
+      call. = FALSE
+    ) # May 4, 2018
+  }
   plan <- sanitize_plan(plan)
   targets <- sanitize_targets(plan, targets)
-  parallelism <- match.arg(
-    parallelism,
-    choices = parallelism_choices(distributed_only = FALSE)
-  )
+  parallelism <- parse_parallelism(parallelism)
+  jobs <- parse_jobs(jobs)
   prework <- add_packages_to_prework(
     packages = packages,
     prework = prework
   )
   if (is.null(cache)) {
     cache <- recover_cache(
-      force = force, verbose = verbose, fetch_cache = fetch_cache)
+      force = force,
+      verbose = verbose,
+      fetch_cache = fetch_cache,
+      console_log_file = console_log_file
+    )
   }
   if (!force){
     assert_compatible_cache(cache = cache)
@@ -399,19 +448,21 @@ drake_config <- function(
   cache <- configure_cache(
     cache = cache,
     overwrite_hash_algos = FALSE,
-    jobs = jobs
+    jobs = jobs,
+    init_common_values = TRUE
   )
   seed <- choose_seed(supplied = seed, cache = cache)
   trigger <- match.arg(arg = trigger, choices = triggers())
   if (is.null(graph)){
     graph <- build_drake_graph(plan = plan, targets = targets,
       envir = envir, verbose = verbose, jobs = jobs,
-      sanitize_plan = FALSE)
+      sanitize_plan = FALSE, console_log_file = console_log_file)
   } else {
     graph <- prune_drake_graph(graph = graph, to = targets, jobs = jobs)
   }
   cache_path <- force_cache_path(cache)
   lazy_load <- parse_lazy_arg(lazy_load)
+  pruning_strategy <- match.arg(pruning_strategy)
   list(
     plan = plan, targets = targets, envir = envir,
     cache = cache, cache_path = cache_path, fetch_cache = fetch_cache,
@@ -422,19 +473,19 @@ drake_config <- function(
     long_hash_algo = cache$get("long_hash_algo", namespace = "config"),
     seed = seed, trigger = trigger,
     timeout = timeout, cpu = cpu, elapsed = elapsed, retries = retries,
-    imports_only = imports_only, skip_imports = skip_imports,
+    skip_targets = skip_targets, skip_imports = skip_imports,
     skip_safety_checks = skip_safety_checks, log_progress = log_progress,
     lazy_load = lazy_load, session_info = session_info,
     cache_log_file = cache_log_file, caching = match.arg(caching),
     evaluator = future::plan("next"), keep_going = keep_going,
-    session = session
+    session = session, pruning_strategy = pruning_strategy,
+    makefile_path = makefile_path, console_log_file = console_log_file,
+    ensure_workers = ensure_workers
   )
 }
 
 add_packages_to_prework <- function(packages, prework) {
-  packages <- c("methods", packages) %>% unique
-  if (!length(packages))
-    return(prework)
+  packages <- unique(c("methods", packages))
   paste0("if(!R.utils::isPackageLoaded(\"", packages, "\")) require(",
     packages, ")", sep = "") %>% c(prework)
 }
@@ -454,7 +505,7 @@ add_packages_to_prework <- function(packages, prework) {
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
-#' load_basic_example() # Get the code with drake_example("basic").
+#' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' # Create a master internal configuration list with prework.
 #' con <- drake_config(my_plan, prework = c("library(knitr)", "x <- 1"))
 #' # Do the prework. Usually done at the beginning of `make()`,
@@ -484,7 +535,7 @@ do_prework <- function(config, verbose_packages) {
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
-#' load_basic_example() # Get the code with drake_example("basic").
+#' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' # List the possible targets you could choose for the
 #' # `targets` argument to make(). You may choose any subset.
 #' possible_targets(my_plan)
@@ -506,7 +557,7 @@ possible_targets <- function(plan = read_drake_plan()) {
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
-#' load_basic_example() # Get the code with drake_example("basic").
+#' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' config <- drake_config(my_plan)
 #' store_drake_config(config = config)
 #' read_drake_config()
@@ -528,3 +579,31 @@ store_drake_config <- function(config) {
   )
   invisible()
 }
+
+parse_jobs <- function(jobs){
+  check_jobs(jobs)
+  if (length(jobs) < 2){
+    c(imports = jobs, targets = jobs)
+  } else {
+    jobs
+  }
+}
+
+parse_parallelism <- function(parallelism){
+  check_parallelism(parallelism)
+  for (i in seq_along(parallelism)){
+    parallelism[i] <- match.arg(
+      arg = parallelism[i],
+      choices = parallelism_choices(distributed_only = FALSE)
+    )
+  }
+  if (length(parallelism) < 2){
+    if (parallelism %in% parallelism_choices(distributed_only = TRUE)){
+      c(imports = default_parallelism(), targets = parallelism)
+    } else {
+      c(imports = parallelism, targets = parallelism)
+    }
+  } else {
+    parallelism
+  }
+}
