@@ -6,7 +6,7 @@
 #' @details If the argument is a `knitr` report
 #'   (for example, `file_store("report.Rmd")` or `"\"report.Rmd\""`)
 #'   the the dependencies of the expected compiled
-#'   output will be given. For example, `deps(file_store("report.Rmd"))`
+#'   output will be given. For example, `deps_code(file_store("report.Rmd"))`
 #'   will return target names found in calls to [loadd()]
 #'   and [readd()] in active code chunks.
 #'   These [loadd()]/[readd()] targets are needed
@@ -20,16 +20,17 @@
 #'   (For example, `file_store("report.Rmd")` is just `"\"report.Rmd\""`.)
 #'
 #'   `Drake` takes special precautions so that a target/import
-#'   does not depend on itself. For example, `deps(f)`` might return
+#'   does not depend on itself. For example, `deps_code(f)`` might return
 #'   `"f"` if `f()` is a recursive function, but [make()] just ignores
 #'   this conflict and runs as expected. In other words, [make()]
 #'   automatically removes all self-referential loops in the dependency
 #'   network.
+#' @seealso deps_targets make drake_plan drake_config
 #' @export
-#' @param x Either a function or a string.
-#'   Strings are commands from your workflow plan data frame.
+#' @param x a language object (code), character string (code as text),
+#'   or imported function to analyze for dependencies.
 #' @return A character vector, names of dependencies.
-#'   Files wrapped in single quotes.
+#'   Files wrapped in escaped double quotes.
 #'   The other names listed are functions or generic R objects.
 #' @examples
 #' # Your workflow likely depends on functions in your workspace.
@@ -40,7 +41,7 @@
 #' # Find the dependencies of f. These could be R objects/functions
 #' # in your workspace or packages. Any file names or target names
 #' # will be ignored.
-#' deps(f)
+#' deps_code(f)
 #' # Define a workflow plan data frame that uses your function f().
 #' my_plan <- drake_plan(
 #'   x = 1 + some_object,
@@ -51,18 +52,20 @@
 #' # Get the dependencies of workflow plan commands.
 #' # Here, the dependencies could be R functions/objects from your workspace
 #' # or packages, imported files, or other targets in the workflow plan.
-#' deps(my_plan$command[1])
-#' deps(my_plan$command[2])
-#' deps(my_plan$command[3])
+#' deps_code(my_plan$command[1])
+#' deps_code(my_plan$command[2])
+#' deps_code(my_plan$command[3])
+#' # New: you can also supply language objects.
+#' deps_code(expression(x + 123))
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
-#' load_basic_example() # Get the code with drake_example("basic").
+#' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' # Dependencies of the knitr-generated targets like 'report.md'
 #' # include targets/imports referenced with `readd()` or `loadd()`.
-#' deps(file_store("report.Rmd"))
+#' deps_code(file_store("report.Rmd"))
 #' })
 #' }
-deps <- function(x){
+deps_code <- function(x){
   if (is.function(x)){
     out <- import_dependencies(x)
   } else if (is_file(x) && file.exists(drake_unquote(x))){
@@ -70,11 +73,48 @@ deps <- function(x){
   } else if (is.character(x)){
     out <- command_dependencies(x)
   } else{
-    stop("x must be a character scalar or function.")
+    out <- code_dependencies(x)
   }
   clean_dependency_list(out)
 }
 
+#' @title List the dependencies of one or more targets
+#' @description Intended for debugging and checking your project.
+#'   The dependency structure of the components of your analysis
+#'   decides which targets are built and when.
+#' @details Unlike [deps_code()], `deps_targets()` allows you to
+#'   specify a set of targets and get their dependencies. This assumes
+#'   you have an output list from [drake_config()]. which resolves
+#'   the dependency graph.
+#' @seealso deps_code make drake_plan drake_config
+#' @export
+#' @param targets a character vector of target names
+#' @param config an output list from [drake_config()]
+#' @param reverse logical, whether to compute reverse dependencies
+#'   (targets immediately downstream) instead of ordinary dependencies. 
+#' @return A character vector, names of dependencies.
+#'   Files wrapped in escaped double quotes.
+#'   The other names listed are functions or generic R objects.
+#' @examples
+#' \dontrun{
+#' test_with_dir("Quarantine side effects.", {
+#' load_mtcars_example() # Get the code with drake_example("mtcars").
+#' # Dependencies of the knitr-generated targets like 'report.md'
+#' # include targets/imports referenced with `readd()` or `loadd()`.
+#' config <- drake_config(my_plan)
+#' deps_targets(file_store("report.md"), config = config)
+#' deps_targets("regression1_small", config = config)
+#' deps_targets(c("small", "large"), config = config, reverse = TRUE)
+#' })
+#' }
+deps_targets <- function(
+  targets,
+  config = read_drake_config(),
+  reverse = FALSE
+){
+  dependencies(targets = targets, config = config, reverse = reverse)
+}
+
 #' @title Return the detailed dependency profile
 #'   of the target.
 #' @description Useful for debugging.
@@ -86,7 +126,7 @@ deps <- function(x){
 #'   when examining the dependencies of the target.
 #' @export
 #' @seealso [read_drake_meta()],
-#'   [deps()], [make()],
+#'   [deps_code()], [make()],
 #'   [config()]
 #' @param target name of the target
 #' @param config configuration list output by
@@ -94,7 +134,7 @@ deps <- function(x){
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
-#' load_basic_example() # Load drake's canonical example.
+#' load_mtcars_example() # Load drake's canonical example.
 #' con <- make(my_plan) # Run the project, build the targets.
 #' # Get some example dependency profiles of targets.
 #' dependency_profile("small", config = con)
@@ -147,7 +187,7 @@ dependency_profile <- function(target, config = drake::read_drake_config()){
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
-#' load_basic_example() # Load the canonical example for drake.
+#' load_mtcars_example() # Load the canonical example for drake.
 #' # List all the targets/imports that are reproducibly tracked.
 #' tracked(my_plan)
 #' })
@@ -180,9 +220,9 @@ dependencies <- function(targets, config, reverse = FALSE){
     clean_dependency_list()
 }
 
-nonfile_target_dependencies <- function(targets, config){
+nonfile_target_dependencies <- function(targets, config, jobs = 1){
   deps <- dependencies(targets = targets, config = config)
-  out <- parallel_filter(x = deps, f = is_not_file, jobs = config$jobs)
+  out <- parallel_filter(x = deps, f = is_not_file, jobs = jobs)
   intersect(out, config$plan$target)
 }
 
@@ -355,7 +395,7 @@ safe_find_globals <- function(expr){
     find_globals(expr),
     error = function(e){
       warning(
-        "could not resolve implicit dependencies of code:",
+        "could not resolve implicit dependencies of code: ",
         head(deparse(expr)),
         call. = FALSE
       )
@@ -364,6 +404,12 @@ safe_find_globals <- function(expr){
   )
 }
 
+quiet_get_inputs <- function(expr){
+  # Warning: In collector$results(reset = reset) :
+  #  partial argument match of 'reset' to 'resetState'
+  suppressWarnings(CodeDepends::getInputs(expr))
+}
+
 find_globals <- function(expr){
   if (is.function(expr)){
     expr <- unwrap_function(expr)
@@ -372,13 +418,12 @@ find_globals <- function(expr){
   } else {
     formals <- character(0)
   }
-  # Warning: In collector$results(reset = reset) :
-  #  partial argument match of 'reset' to 'resetState'
-  suppressWarnings(inputs <- CodeDepends::getInputs(expr))
+  inputs <- quiet_get_inputs(expr)
   base::union(
     inputs@inputs,
     names(inputs@functions)
   ) %>%
+    base::union(inputs@nsevalVars) %>%
     setdiff(y = c(formals, drake_fn_patterns, ".")) %>%
     Filter(f = is_parsable)
 }
@@ -397,19 +442,19 @@ analyze_readd <- function(expr){
 }
 
 analyze_file_in <- function(expr){
-  inputs <- CodeDepends::getInputs(expr)
+  inputs <- quiet_get_inputs(expr)
   deps <- drake_quotes(c(inputs@strings, inputs@files), single = FALSE)
   list(file_in = deps)
 }
 
 analyze_file_out <- function(expr){
-  inputs <- CodeDepends::getInputs(expr)
+  inputs <- quiet_get_inputs(expr)
   deps <- drake_quotes(c(inputs@strings, inputs@files), single = FALSE)
   list(file_out = deps)
 }
 
 analyze_knitr_in <- function(expr){
-  inputs <- CodeDepends::getInputs(expr)
+  inputs <- quiet_get_inputs(expr)
   files <- c(inputs@strings, inputs@files)
   out <- lapply(files, knitr_deps_list) %>%
     Reduce(f = merge_lists)
@@ -418,22 +463,9 @@ analyze_knitr_in <- function(expr){
   out
 }
 
-analyze_target_call <- function(expr){
-  out <- as.list(expr)
-  out[nzchar(names(out))] %>%
-    purrr::map(.f = function(x){
-      if (is.language(x)){
-        wide_deparse(x)
-      } else {
-        x
-      }
-    }) %>%
-    tibble::as_tibble()
-}
-
 parse_loadd_arg_list <- function(expr){
   lapply(as.list(expr)[-1], function(arg){
-    inputs <- CodeDepends::getInputs(arg)
+    inputs <- quiet_get_inputs(arg)
     c(inputs@strings, inputs@inputs)
   })
 }
@@ -471,12 +503,8 @@ is_callish <- function(x){
   length(x) > 0 && is.language(x) && (is.call(x) || is.recursive(x))
 }
 
-# This function is just to set up the prefixes and patterns below.
-# Existing tests will fail if the output is incorrect.
-# pair_text is not really needed currently, but in case we have synonyms,
-# we might keep it around for now.
 pair_text <- function(x, y){
-  apply(expand.grid(x, y), 1, paste0, collapse = "") # nocov
+  apply(expand.grid(x, y), 1, paste0, collapse = "")
 }
 
 drake_prefix <- c("", "drake::", "drake:::")
