@@ -78,7 +78,7 @@ as_file <- function(x){
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
-#' load_basic_example() # Get the code with drake_example("basic").
+#' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' # Choose future's multicore parallel backend.
 #' library(future)
 #' future::plan(multicore) # Instead of backend(). Avoid drake::plan().
@@ -296,7 +296,7 @@ default_system2_args <- function(jobs, verbose){
     )
   )
   out <- paste0("--jobs=", jobs)
-  if (!verbose){
+  if (verbose < 1){
     out <- c(out, "--silent")
   }
   return(out)
@@ -321,6 +321,56 @@ deprecate_wildcard <- function(plan, old, replacement){
   plan
 }
 
+#' @title Deprecated.
+#'   List the dependencies of a function, workflow plan command,
+#'   or knitr report source file.
+#' @description Deprecated. Use [deps_code()] or [deps_targets()] instead.
+#'   These functions are intended for debugging and checking your project.
+#'   The dependency structure of the components of your analysis
+#'   decides which targets are built and when.
+#' @details If the argument is a `knitr` report
+#'   (for example, `file_store("report.Rmd")` or `"\"report.Rmd\""`)
+#'   the the dependencies of the expected compiled
+#'   output will be given. For example, `deps(file_store("report.Rmd"))`
+#'   will return target names found in calls to [loadd()]
+#'   and [readd()] in active code chunks.
+#'   These [loadd()]/[readd()] targets are needed
+#'   in order to run `knit(knitr_in("report.Rmd"))`
+#'   to produce the output file `"report.md"`, so technically,
+#'   they are dependencies of `"report.md"`, not `"report.Rmd"`.
+#'
+#'   The [file_store()] function
+#'   alerts `drake` utility functions to file names by
+#'   enclosing them in literal double quotes.
+#'   (For example, `file_store("report.Rmd")` is just `"\"report.Rmd\""`.)
+#'
+#'   `Drake` takes special precautions so that a target/import
+#'   does not depend on itself. For example, `deps(f)`` might return
+#'   `"f"` if `f()` is a recursive function, but [make()] just ignores
+#'   this conflict and runs as expected. In other words, [make()]
+#'   automatically removes all self-referential loops in the dependency
+#'   network.
+#' @export
+#' @keywords internal
+#' @param x Either a function or a string.
+#'   Strings are commands from your workflow plan data frame.
+#' @return A character vector, names of dependencies.
+#'   Files wrapped in single quotes.
+#'   The other names listed are functions or generic R objects.
+#' @examples
+#' # See deps_code() for examples.
+deps <- function(x){
+  .Deprecated(
+    "deps_code()",
+    package = "drake",
+    msg = paste(
+      "drake::deps() is deprecated.",
+      "Use deps_code() or deps_targets() instead."
+    )
+  )
+  deps_code(x)
+}
+
 # Deprecated on 2018-02-15
 doc_of_function_call <- function(expr){
   args <- as.list(expr)[-1]
@@ -539,6 +589,109 @@ is_function_call <- function(
     paste0(c("", paste0(package, c("::", ":::"))), what)
 }
 
+#' @title Deprecated function `load_basic_example`
+#' @description Use [load_mtcars_example()] instead.
+#' @details Deprecated on 2018-04-21.
+#' @seealso [load_mtcars_example()]
+#' @export
+#' @keywords internal
+#' @return A config list, as in [load_mtcars_example()].
+#' @inheritParams load_mtcars_example
+#' @examples
+#' # See ?load_mtcars_example for examples.
+load_basic_example <- function(
+  envir = parent.frame(),
+  seed = NULL,
+  cache = NULL,
+  report_file = "report.Rmd",
+  overwrite = FALSE,
+  to = report_file,
+  verbose = drake::default_verbose(),
+  force = FALSE
+){
+  .Deprecated(
+    "load_basic_example",
+    package = "drake",
+    msg = paste(
+      "load_basic_example() is deprecated",
+      "Use load_mtcars_example() instead."
+    )
+  )
+  load_mtcars_example(
+    envir = envir,
+    seed = seed,
+    cache = cache,
+    report_file = report_file,
+    overwrite = overwrite,
+    to = to,
+    verbose = verbose,
+    force = force
+  )
+}
+
+#' @title Deprecated function
+#' @description Do not use this function. `Drake`'s parallel algorithm
+#'   has changed since version 5.1.2, so `max_useful_jobs()`
+#'   will give you the wrong idea of how many jobs to use. Instead,
+#'   use the [predict_runtime()] function with a sensible value
+#'   for `known_times` and `default_time`
+#'   to cover any targets not built so far.
+#' @details Deprecated on May 4, 2018.
+#' @export
+#' @keywords internal
+#' @return A numeric scalar, the maximum number of useful jobs for
+#'   \code{\link{make}(..., jobs = ...)}.
+#' @seealso [predict_runtime()]
+#' @param config internal configuration list of \code{\link{make}(...)},
+#'   produced also with [drake_config()].
+#' @param imports Set the `imports` argument to change your
+#'   assumptions about how fast objects/files are imported.
+#' @param from_scratch logical, whether to assume
+#'   the next [make()] will run from scratch
+#'   so that all targets are attempted.
+#' @examples
+#' # Do not use this function. Use predict_runtime() instead.
+#' # Pay special attention to the force_times and default_time
+#' # arguments.
+max_useful_jobs <- function(
+  config = drake::read_drake_config(),
+  imports = c("files", "all", "none"),
+  from_scratch = FALSE
+){
+  .Deprecated(
+    "predict_runtime",
+    package = "drake",
+    msg = c(
+      "Do not use max_useful_jobs(). ",
+      "Drake's parallel scheduling algorithm has changed, ",
+      "so max_useful_jobs() will give you the wrong idea about ",
+      "how many jobs to assign to `make()`. For a better estimate, ",
+      "play around with predict_runtime() with sensible values, ",
+      "for force_times and default_time."
+    )
+  )
+  # nocov start
+  imports <- match.arg(imports)
+  nodes <- dataframes_graph(config, from_scratch = from_scratch)$nodes
+  if (imports == "none"){
+    nodes <- nodes[nodes$status != "imported", ]
+  } else if (imports == "files"){
+    nodes <- nodes[nodes$status != "imported" | nodes$type == "file", ]
+  }
+  if (!from_scratch){
+    nodes <- nodes[nodes$status != "outdated", ]
+  }
+  if (!nrow(nodes)){
+    return(0)
+  }
+  level <- NULL
+  n_per_level <- group_by(nodes, level) %>%
+    mutate(nrow = n())
+  max(n_per_level$nrow)
+  # nocov end
+}
+
+
 #' @title Deprecated function `plan`
 #' @description Use [drake_plan()] instead.
 #' @details Deprecated on 2017-10.
@@ -765,6 +918,53 @@ plot_graph <- function(
   )
 }
 
+#' @title Defunct
+#' @description This function is now moot because
+#' staged parallelism in `drake` was replaced
+#' by a much better scheduling algorithm.
+#' @export
+#' @keywords internal
+#' @details Made defunct on May 4, 2018
+#' @examples
+#' # Do not use this function.
+#' @return A data frame of times of the worst-case scenario
+#'   rate-limiting targets in each parallelizable stage.
+#' @param config option internal runtime parameter list of
+#'   \code{\link{make}(...)},
+#'   produced by both [make()] and
+#'   [drake_config()].
+#' @param targets Character vector, names of targets.
+#'   Find the rate-limiting times for building these targets
+#'   plus dependencies.
+#'   Defaults to all targets.
+#' @param from_scratch logical, whether to assume
+#'   next hypothetical call to [make()]
+#'   is a build from scratch (after [clean()]).
+#' @param targets_only logical, whether to factor in just the
+#'   targets or use times from everything, including the imports.
+#' @param future_jobs hypothetical number of jobs
+#'   assumed for the predicted runtime.
+#'   assuming this number of jobs.
+#' @param digits number of digits for rounding the times.
+rate_limiting_times <- function(
+  config = drake::read_drake_config(),
+  targets = NULL,
+  from_scratch = FALSE,
+  targets_only = FALSE,
+  future_jobs = 1,
+  digits = 3
+){
+  .Defunct(
+    package = "drake",
+    msg = c(
+      "The rate_limiting_times() function is moot ",
+      "because drake has replaced staged parallelism ",
+      "with a much better algorithm. ",
+      "Do not use rate_limiting_times()."
+    )
+  )
+}
+
 #' @title Deprecated function `read_config`
 #' @description Use [read_drake_config()] instead.
 #' @details Deprecated on 2017-11-12.
@@ -1031,6 +1231,37 @@ session <- function(
   )
 }
 
+#' @title Defunct function
+#' @description Staged parallelism is removed from drake,
+#' so this function is moot.
+#' Drake uses a much better parallel algorithm now.
+#' @details Made defunct on May 4, 2018.
+#' @export
+#' @keywords internal
+#' @return A data frame of information spelling out how
+#'   targets are divided into parallelizable stages
+#'   (according to the `stage` column).
+#' @param config An configuration list output by
+#'   [make()] or [drake_config()].
+#' @param from_scratch logical, whether to assume
+#'   that the next [make()] will run from scratch
+#'   so that all targets are attempted.
+#' @examples
+#' # Do not use this function.
+parallel_stages <- function(
+  config = drake::read_drake_config(),
+  from_scratch = FALSE
+){
+  .Defunct(
+    package = "drake",
+    msg = c(
+      "Staged parallelism is removed from drake, ",
+      "so the parallel_stages() function is moot. ",
+      "Drake uses a much better parallel algorithm now."
+    )
+  )
+}
+
 #' @title Deprecated function `summaries`
 #' @description Use [summaries()] instead
 #' @details Deprecated on 2017-11-12.
