@@ -15,10 +15,13 @@
 #'   (just like `character.only` in [library()]).
 #' @param namespace optional character string,
 #'   name of the `storr` namespace to read from.
+#' @param show_source logical, option to show the command
+#'   that produced the target or indicate that the object
+#'   was imported (using [show_source()]).
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
-#' load_basic_example() # Get the code with drake_example("basic").
+#' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' make(my_plan) # Run the project, build the targets.
 #' readd(reg1) # Return imported object 'reg1' from the cache.
 #' readd(small) # Return targets 'small' from the cache.
@@ -34,7 +37,8 @@ readd <- function(
   search = TRUE,
   cache = drake::get_cache(path = path, search = search, verbose = verbose),
   namespace = NULL,
-  verbose = drake::default_verbose()
+  verbose = drake::default_verbose(),
+  show_source = FALSE
 ){
   # if the cache is null after trying get_cache:
   if (is.null(cache)){
@@ -46,6 +50,13 @@ readd <- function(
   if (is.null(namespace)){
     namespace <- cache$default_namespace
   }
+  if (show_source){
+    show_source(
+      target = target,
+      config = list(cache = cache),
+      character_only = TRUE
+    )
+  }
   cache$get(
     standardize_filename(target),
     namespace = namespace,
@@ -68,6 +79,7 @@ readd <- function(
 #' @return `NULL`
 #'
 #' @inheritParams cached
+#' @inheritParams readd
 #'
 #' @param ... targets to load from the cache: as names (symbols),
 #'   character strings, or `dplyr`-style `tidyselect`
@@ -125,7 +137,7 @@ readd <- function(
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
-#' load_basic_example() # Get the code with drake_example("basic").
+#' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' make(my_plan) # Run the projects, build the targets.
 #' loadd(small) # Load target 'small' into your workspace.
 #' small
@@ -170,7 +182,8 @@ loadd <- function(
   deps = FALSE,
   lazy = "eager",
   graph = NULL,
-  replace = TRUE
+  replace = TRUE,
+  show_source = FALSE
 ){
   force(envir)
   if (is.null(cache)){
@@ -211,6 +224,14 @@ loadd <- function(
     cache = cache,
     jobs = jobs
   )
+  if (show_source){
+    lapply(
+      X = targets,
+      FUN = show_source,
+      config = list(cache = cache),
+      character_only = TRUE
+    )
+  }
   lightly_parallelize(
     X = targets, FUN = load_target, cache = cache,
     namespace = namespace, envir = envir,
@@ -368,7 +389,7 @@ bind_load_target <- function(target, cache, namespace, envir, verbose){
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
-#' load_basic_example() # Get the code with drake_example("basic").
+#' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' make(my_plan) # Run the project, build the targets.
 #' # Retrieve the master internal configuration list from the cache.
 #' read_drake_config()
@@ -425,7 +446,7 @@ read_drake_config <- function(
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
-#' load_basic_example() # Get the code with drake_example("basic").
+#' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' make(my_plan) # Run the project, build the targets.
 #' # Retrieve the igraph network from the cache.
 #' g <- read_drake_graph()
@@ -464,7 +485,7 @@ read_drake_graph <- function(
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
-#' load_basic_example() # Get the code with drake_example("basic").
+#' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' make(my_plan) # Run the project, build the targets.
 #' read_drake_plan() # Retrieve the workflow plan data frame from the cache.
 #' })
