@@ -1,7 +1,7 @@
 # Here, load the packages you need for your workflow.
 
-library(drake)
 library(cranlogs)
+library(drake)
+library(dplyr)
 library(ggplot2)
 library(knitr)
-library(plyr)
