@@ -6,14 +6,7 @@ library(future.batchtools)
 library(drake)
 
 # Use future::plan(multicore) instead for a dry run.
-future::plan(
-  batchtools_torque,
-  template = "torque.tmpl",
-  workers = 4
-)
+future::plan(batchtools_torque, template = "torque.tmpl")
 
-load_basic_example()
-make(
-  my_plan,
-  parallelism = "future_lapply"
-)
+load_mtcars_example()
+make(my_plan, parallelism = "future", jobs = 4)
