@@ -1,10 +1,12 @@
 drake_context("console")
 
 test_with_dir("console_cache", {
-  expect_silent(console_cache("12345", verbose = TRUE))
-  expect_message(console_cache("12345", verbose = 2))
-  expect_silent(console_cache(NULL, verbose = TRUE))
-  expect_message(console_cache(NULL, verbose = 2))
+  expect_silent(
+    console_cache(config = list(cache_path = "123", verbose = TRUE)))
+  expect_message(
+    console_cache(config = list(cache_path = "123", verbose = 2)))
+  expect_silent(console_cache(config = list(verbose = TRUE)))
+  expect_message(console_cache(config = list(verbose = 2)))
 })
 
 test_with_dir("console_up_to_date", {
@@ -13,7 +15,7 @@ test_with_dir("console_up_to_date", {
   expect_silent(console_up_to_date(con))
   con$verbose <- TRUE
   expect_silent(console_up_to_date(con))
-  con$cache$clear(namespace = "session")
+  con$cache$clear(namespace = "attempt")
   con <- make(pl, verbose = FALSE, session_info = FALSE)
   con$verbose <- TRUE
   expect_message(console_up_to_date(con))
@@ -118,3 +120,80 @@ test_with_dir("console_many_targets() works", {
   expect_true(is.character(tmp))
   expect_true(nchar(tmp) <= getOption("width") + 20)
 })
+
+test_with_dir("console_persistent_workers", {
+  con <- dbug()
+  expect_silent(console_persistent_workers(con))
+  con$verbose <- 4
+  expect_message(console_persistent_workers(con))
+})
+
+test_with_dir("console_skip", {
+  con <- dbug()
+  expect_silent(console_skip("bla", con))
+  con$verbose <- 4
+  expect_message(console_skip(file_store("bla"), con))
+})
+
+test_with_dir("console to file", {
+  load_mtcars_example()
+  cache <- storr::storr_environment()
+  expect_false(file.exists("log.txt"))
+  tmp <- capture.output({
+      make(
+        my_plan, cache = cache, verbose = 4, session_info = FALSE,
+        console_log_file = "log.txt"
+      )
+      make(
+        my_plan, cache = cache, verbose = 4, session_info = FALSE,
+        console_log_file = "log.txt"
+      )
+      make(
+        my_plan, cache = cache, verbose = 4, session_info = FALSE,
+        trigger = "always", console_log_file = "log.txt"
+      )
+    },
+    type = "message"
+  )
+  expect_equal(tmp, character(0))
+  expect_true(length(readLines("log.txt")) > 0)
+})
+
+test_with_dir("drake_warning() and drake_error()", {
+  plan <- drake_plan(x = {
+      message("some_message")
+      warning("some_warning")
+      stop("some_error")
+    },
+    strings_in_dots = "literals"
+  )
+  expect_error(expect_warning(make(
+    plan, cache = storr::storr_environment(),
+    session_info = FALSE
+  )))
+  expect_false(file.exists("log.txt"))
+  expect_error(expect_warning(make(
+    plan, console_log_file = "log.txt",
+    cache = storr::storr_environment(),
+    session_info = FALSE
+  )))
+  x <- readLines("log.txt")
+  expect_true(any(grepl("some_message", x)))
+  expect_true(any(grepl("some_warning", x)))
+  expect_true(any(grepl("some_error", x)))
+})
+
+test_with_dir("show_source()", {
+  plan <- drake_plan(x = rnorm(15))
+  cache <- storr::storr_environment()
+  make(plan, cache = cache, session_info = FALSE)
+  config <- drake_config(plan, cache = cache)
+  expect_message(show_source(x, config), regexp = "command")
+  expect_message(show_source(rnorm, config), regexp = "import")
+  expect_silent(loadd(x, cache = cache, show_source = FALSE))
+  expect_silent(readd(x, cache = cache, show_source = FALSE))
+  expect_message(loadd(x, cache = cache, show_source = TRUE))
+  expect_message(y <- readd(x, cache = cache, show_source = TRUE))
+  expect_true(is.numeric(x))
+  expect_true(is.numeric(y))
+})
