@@ -12,14 +12,14 @@ test_with_dir("examples are listed and written", {
   }
   expect_warning(drake_example(destination = getwd()))
   expect_silent(drake_batchtools_tmpl_file("slurm"))
-  expect_error(drake_batchtools_tmpl_file("basic"))
+  expect_error(drake_batchtools_tmpl_file("mtcars"))
 })
 
 test_with_dir("overwrites of report.Rmd handled correctly", {
-  load_basic_example(overwrite = TRUE)
-  load_basic_example(overwrite = FALSE)
-  expect_warning(load_basic_example(overwrite = TRUE))
-  expect_warning(load_basic_example(to = "a", report_file = "b"))
+  load_mtcars_example(overwrite = TRUE)
+  load_mtcars_example(overwrite = FALSE)
+  expect_warning(load_mtcars_example(overwrite = TRUE))
+  expect_warning(load_mtcars_example(to = "a", report_file = "b"))
   expect_true(file.exists("b"))
   expect_false(file.exists("a"))
 })
